@@ -1,10 +1,12 @@
-caSegmentation<-function(y,x,c=3)
+caSegmentation<-function(y,x,c=2)
 {
 	options(contrasts=c("contr.sum","contr.poly"))
 	outdec<-options(OutDec="."); on.exit(options(outdec))
 	options(OutDec=",")
 	y<-m2v(y)
 	Usi<-caTotalUtilities(y,x)
-	segm<-kmeans(Usi,Usi[initial.Centers(Usi,c),])
-	return(segm)
+	set.seed(123)
+	seg<-kmeans(Usi,c)
+	segment<-list(segm=seg,util=Usi,sclu=seg$cluster)
+	return(segment)
 }
\ No newline at end of file
